//
//  IFXPDFBrush.h
//  IFXPDFFactory
//
//  Created by Sorin Nistor on 5/2/12.
//  Copyright (c) 2012 iPDFdev.com. All rights reserved.
//

#import <Foundation/Foundation.h>

@class IFXPDFColor;

/** This class defines a PDF brush. A brush is used to fill the interior of path objects. */
@interface IFXPDFBrush : NSObject {
    IFXPDFColor* color;
}

///-----------------------------------
/// @name Color handling
///-----------------------------------

/** Gets or sets the brush color.  
 * @see IFXPDFColor
 */
@property (nonatomic, retain) IFXPDFColor* color;

///-----------------------------------
/// @name Initialization & Disposal
///-----------------------------------

/** Creates a new brush with a default RGB black color. */
- (id) init;

/** Creates a new brush with the specified color.
 * @param brushColor the color of the brush
 * @see IFXPDFColor
 */
- (id) initWithColor: (IFXPDFColor*) brushColor;

- (void) dealloc;

/** Creates a new autoreleased brush with the specified color. 
 * @param brushColor the color of the brush
 * @see IFXPDFColor
 */
+ (IFXPDFBrush*) brushWithColor: (IFXPDFColor*) brushColor;

@end
