//
//  IFXPDFGraphics.h
//  IFXPDFFactory
//
//  Created by Sorin Nistor on 4/29/12.
//  Copyright (c) 2012 iPDFdev.com. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "IFXPDFGraphicsEnums.h"

@class IFXPDFContentStreamContainer;
@class IFXPDFStreamDictionary;
@class IFXPDFColor;
@class IFXPDFColorSpace;
@class IFXPDFPen;
@class IFXPDFBrush;
@class IFXPDFGraphicsState;
@class IFXPDFPoint;
@class IFXPDFPath;
@class IFXPDFImage;
@class IFXPDFBaseFont;
@class IFXPDFFormXObject;
@class IFXPDFMatrix;

@interface IFXPDFGraphics : NSObject {
    IFXPDFContentStreamContainer* _container;
    IFXPDFStreamDictionary* _cosStream;
    NSMutableArray* _graphicsStateStack;
}

- (id) init;
- (void) dealloc;

- (void) drawLineWithPen: (IFXPDFPen*) pen fromX1: (double) x1 y1: (double) y1 toX2: (double) x2 y2: (double) y2;
- (void) drawLineWithPen: (IFXPDFPen*) pen fromPoint: (IFXPDFPoint*) pt1 toPoint: (IFXPDFPoint*) pt2;

- (void) drawRectangleWithPen: (IFXPDFPen*) pen 
                          atX: (double) x y: (double) y
                    withWidth: (double) width height: (double) height;
- (void) drawRectangleWithPen: (IFXPDFPen*) pen 
                          atX: (double) x y: (double) y
                    withWidth: (double) width height: (double) height
                     rotation: (double) rotation;
- (void) drawRectangleWithBrush: (IFXPDFBrush*) brush 
                            atX: (double) x y: (double) y
                      withWidth: (double) width height: (double) height;
- (void) drawRectangleWithBrush: (IFXPDFBrush*) brush 
                            atX: (double) x y: (double) y
                      withWidth: (double) width height: (double) height
                       rotation: (double) rotation;
- (void) drawRectangleWithPen: (IFXPDFPen*) pen andBrush: (IFXPDFBrush*) brush
                          atX: (double) x y: (double) y
                    withWidth: (double) width height: (double) height;
- (void) drawRectangleWithPen: (IFXPDFPen*) pen andBrush: (IFXPDFBrush*) brush 
                          atX: (double) x y: (double) y
                    withWidth: (double) width height: (double) height
                     rotation: (double) rotation;

- (void) drawRoundRectangleWithPen: (IFXPDFPen*) pen 
                               atX: (double) x y: (double) y 
                         withWidth: (double) width height: (double) height
                      ellipseWidth: (double) ellipseWidth ellipseHeight: (double) ellipseHeight;
- (void) drawRoundRectangleWithPen: (IFXPDFPen*) pen 
                               atX: (double) x y: (double) y 
                         withWidth: (double) width height: (double) height 
                      ellipseWidth: (double) ellipseWidth ellipseHeight: (double) ellipseHeight
                          rotation: (double) rotation;
- (void) drawRoundRectangleWithBrush: (IFXPDFBrush*) brush 
                                 atX: (double) x y: (double) y 
                           withWidth: (double) width height: (double) height
                        ellipseWidth: (double) ellipseWidth ellipseHeight: (double) ellipseHeight;
- (void) drawRoundRectangleWithBrush: (IFXPDFBrush*) brush 
                                 atX: (double) x y: (double) y 
                           withWidth: (double) width height: (double) height 
                        ellipseWidth: (double) ellipseWidth ellipseHeight: (double) ellipseHeight
                            rotation: (double) rotation;
- (void) drawRoundRectangleWithPen: (IFXPDFPen*) pen andBrush: (IFXPDFBrush*) brush
                               atX: (double) x y: (double) y 
                         withWidth: (double) width height: (double) height
                      ellipseWidth: (double) ellipseWidth ellipseHeight: (double) ellipseHeight;
- (void) drawRoundRectangleWithPen: (IFXPDFPen*) pen andBrush: (IFXPDFBrush*) brush 
                               atX: (double) x y: (double) y 
                         withWidth: (double) width height: (double) height 
                      ellipseWidth: (double) ellipseWidth ellipseHeight: (double) ellipseHeight
                          rotation: (double) rotation;

- (void) drawPath: (IFXPDFPath*) path withPen: (IFXPDFPen*) pen;
- (void) drawPath: (IFXPDFPath*) path withBrush: (IFXPDFBrush*) brush;
- (void) drawPath: (IFXPDFPath*) path withBrush: (IFXPDFBrush*) brush fillMode: (IFXPDFFillMode) fillMode;
- (void) drawPath: (IFXPDFPath*) path withPen: (IFXPDFPen*) pen andBrush: (IFXPDFBrush*) brush;
- (void) drawPath: (IFXPDFPath*) path
          withPen: (IFXPDFPen*) pen andBrush: (IFXPDFBrush*) brush
         fillMode: (IFXPDFFillMode) fillMode;

- (void) drawEllipseWithPen: (IFXPDFPen*) pen 
                        atX: (double) x 
                          y: (double) y 
                  withWidth: (double) width 
                     height: (double) height;
- (void) drawEllipseWithPen: (IFXPDFPen*) pen 
                        atX: (double) x 
                          y: (double) y 
                  withWidth: (double) width 
                     height: (double) height 
                   rotation: (double) rotation;
- (void) drawEllipseWithBrush: (IFXPDFBrush*) brush 
                          atX: (double) x 
                            y: (double) y 
                    withWidth: (double) width 
                       height: (double) height;
- (void) drawEllipseWithBrush: (IFXPDFBrush*) brush 
                          atX: (double) x 
                            y: (double) y 
                    withWidth: (double) width 
                       height: (double) height 
                     rotation: (double) rotation;
- (void) drawEllipseWithPen: (IFXPDFPen*) pen 
                   andBrush: (IFXPDFBrush*) brush
                        atX: (double) x 
                          y: (double) y 
                  withWidth: (double) width 
                     height: (double) height;
- (void) drawEllipseWithPen: (IFXPDFPen*) pen 
                   andBrush: (IFXPDFBrush*) brush 
                        atX: (double) x 
                          y: (double) y 
                  withWidth: (double) width 
                     height: (double) height 
                   rotation: (double) rotation;

- (void) drawArcWithPen: (IFXPDFPen*) pen
                    atX: (double) x y: (double) y
              withWidth: (double) width height: (double) height
             startAngle: (double) startAngle sweepAngle: (double) sweepAngle;
- (void) drawArcWithPen: (IFXPDFPen*) pen
                    atX: (double) x y: (double) y
              withWidth: (double) width height: (double) height
             startAngle: (double) startAngle sweepAngle: (double) sweepAngle
               rotation: (double) rotation;
- (void) drawArcWithBrush: (IFXPDFBrush*) pen
                      atX: (double) x y: (double) y
                withWidth: (double) width height: (double) height
               startAngle: (double) startAngle sweepAngle: (double) sweepAngle;
- (void) drawArcWithBrush: (IFXPDFBrush*) pen
                      atX: (double) x y: (double) y
                withWidth: (double) width height: (double) height
               startAngle: (double) startAngle sweepAngle: (double) sweepAngle
                 rotation: (double) rotation;
- (void) drawArcWithPen: (IFXPDFPen*) pen andBrush: (IFXPDFBrush*) brush
                    atX: (double) x y: (double) y
              withWidth: (double) width height: (double) height
             startAngle: (double) startAngle sweepAngle: (double) sweepAngle;
- (void) drawArcWithPen: (IFXPDFPen*) pen andBrush: (IFXPDFBrush*) brush
                    atX: (double) x y: (double) y
              withWidth: (double) width height: (double) height
             startAngle: (double) startAngle sweepAngle: (double) sweepAngle
               rotation: (double) rotation;

- (void) drawPieWithPen: (IFXPDFPen*) pen
                    atX: (double) x y: (double) y
              withWidth: (double) width height: (double) height
             startAngle: (double) startAngle sweepAngle: (double) sweepAngle;
- (void) drawPieWithPen: (IFXPDFPen*) pen
                    atX: (double) x y: (double) y
              withWidth: (double) width height: (double) height
             startAngle: (double) startAngle sweepAngle: (double) sweepAngle rotation: (double) rotation;
- (void) drawPieWithBrush: (IFXPDFBrush*) brush
                      atX: (double) x y: (double) y
                withWidth: (double) width height: (double) height
               startAngle: (double) startAngle sweepAngle: (double) sweepAngle;
- (void) drawPieWithBrush: (IFXPDFBrush*) brush
                      atX: (double) x y: (double) y
                withWidth: (double) width height: (double) height
               startAngle: (double) startAngle sweepAngle: (double) sweepAngle rotation: (double) rotation;
- (void) drawPieWithPen: (IFXPDFPen*) pen andBrush: (IFXPDFBrush*) brush
                    atX: (double) x y: (double) y
              withWidth: (double) width height: (double) height
             startAngle: (double) startAngle sweepAngle: (double) sweepAngle;
- (void) drawPieWithPen: (IFXPDFPen*) pen andBrush: (IFXPDFBrush*) brush
                    atX: (double) x y: (double) y
              withWidth: (double) width height: (double) height
             startAngle: (double) startAngle sweepAngle: (double) sweepAngle rotation: (double) rotation;

- (void) drawChordWithPen: (IFXPDFPen*) pen
                      atX: (double) x
                        y: (double) y
                withWidth: (double) width
                   height: (double) height
               startAngle: (double) startAngle
               sweepAngle: (double) sweepAngle;
- (void) drawChordWithBrush: (IFXPDFBrush*) brush
                        atX: (double) x
                          y: (double) y
                  withWidth: (double) width
                     height: (double) height
                 startAngle: (double) startAngle
                 sweepAngle: (double) sweepAngle;
- (void) drawChordWithPen: (IFXPDFPen*) pen
                 andBrush: (IFXPDFBrush*) brush
                      atX: (double) x
                        y: (double) y
                withWidth: (double) width
                   height: (double) height
               startAngle: (double) startAngle
               sweepAngle: (double) sweepAngle;

- (void) drawBezierWithPen: (IFXPDFPen*) pen
                      atX1: (double) x1 y1: (double) y1
                        x2: (double) x2 y2: (double) y2
                        x3: (double) x3 y3: (double) y3
                        x4: (double) x4 y4: (double) y4;
- (void) drawBezierWithPen: (IFXPDFPen*) pen
                  atPoint1: (IFXPDFPoint*) pt1
                    point2: (IFXPDFPoint*) pt2
                    point2: (IFXPDFPoint*) pt3
                    point4: (IFXPDFPoint*) pt4;

- (void) drawText: (NSString*) text
         withFont: (IFXPDFBaseFont*) font brush: (IFXPDFBrush*) brush
              atX: (double) x y: (double) y;
- (void) drawText: (NSString*) text
         withFont: (IFXPDFBaseFont*) font brush: (IFXPDFBrush*) brush
              atX: (double) x y: (double) y rotation: (double) rotation;
- (void) drawText: (NSString*) text
         withFont: (IFXPDFBaseFont*) font brush: (IFXPDFBrush*) brush
              atX: (double) x y: (double) y rotation: (double) rotation
  horizontalAlign: (IFXPDFTextHorizontalAlign) horizontalAlign verticalAlign: (IFXPDFTextVerticalAlign) verticalAlign;
- (void) drawText: (NSString*) text
         withFont: (IFXPDFBaseFont*) font pen: (IFXPDFPen*) pen brush: (IFXPDFBrush*) brush
              atX: (double) x y: (double) y rotation: (double) rotation
  horizontalAlign: (IFXPDFTextHorizontalAlign) horizontalAlign verticalAlign: (IFXPDFTextVerticalAlign) verticalAlign;

- (void) drawTextBox: (NSString*) text
            withFont: (IFXPDFBaseFont*) font brush: (IFXPDFBrush*) brush
                 atX: (double) x y: (double) y width: (double) width height: (double) height;
- (void) drawTextBox: (NSString*) text
            withFont: (IFXPDFBaseFont*) font brush: (IFXPDFBrush*) brush
                 atX: (double) x y: (double) y width: (double) width height: (double) height rotation: (double) rotation;
- (void) drawTextBox: (NSString*) text
            withFont: (IFXPDFBaseFont*) font brush: (IFXPDFBrush*) brush
                 atX: (double) x y: (double) y width: (double) width height: (double) height rotation: (double) rotation
     horizontalAlign: (IFXPDFTextHorizontalAlign) horizontalAlign
       verticalAlign: (IFXPDFTextVerticalAlign) verticalAlign;
- (void) drawTextBox: (NSString*) text
            withFont: (IFXPDFBaseFont*) font pen: (IFXPDFPen*) pen brush: (IFXPDFBrush*) brush
                 atX: (double) x y: (double) y width: (double) width height: (double) height rotation: (double) rotation
     horizontalAlign: (IFXPDFTextHorizontalAlign) horizontalAlign
       verticalAlign: (IFXPDFTextVerticalAlign) verticalAlign;

- (void) setClippingPath: (IFXPDFPath*) clipPath;
- (void) saveGraphicsState;
- (void) restoreGraphicsState;

- (void) multiplyTransformWithMatrix: (IFXPDFMatrix*) matrix;
- (void) multiplyTransformWithM11: (double) m11 
                              m12: (double) m12 
                              m21: (double) m21 
                              m22: (double) m22 
                               tx: (double) tx 
                               ty: (double) ty;
- (void) translateTransformWithTx: (double) tx andTy: (double) ty;
- (void) scaleTransformWithSx: (double) sx andSy: (double) sy;
- (void) rotateTransformWithAngle: (double) angle;

- (void) drawFormXObject: (IFXPDFFormXObject*) xObject
                     atX: (double) x 
                       y: (double) y
               withWidth: (double) width 
                  height: (double) height;
- (void) drawFormXObject: (IFXPDFFormXObject*) xObject
                     atX: (double) x 
                       y: (double) y
               withWidth: (double) width 
                  height: (double) height
                rotation: (double) rotation;
- (void) drawFormXObject: (IFXPDFFormXObject*) xObject
                     atX: (double) x 
                       y: (double) y
               withWidth: (double) width 
                  height: (double) height
                rotation: (double) rotation
                    flip: (IFXPDFContentFlip) contentFlip;

- (void) drawImage: (IFXPDFImage*) image
               atX: (double) x 
                 y: (double) y
         withWidth: (double) width 
            height: (double) height;
- (void) drawImage: (IFXPDFImage*) image
               atX: (double) x 
                 y: (double) y
         withWidth: (double) width 
            height: (double) height
          rotation: (double) rotation;
- (void) drawImage: (IFXPDFImage*) image
               atX: (double) x 
                 y: (double) y
         withWidth: (double) width 
            height: (double) height
          rotation: (double) rotation
              flip: (IFXPDFContentFlip) contentFlip;

@end
