//
//  IFXFDetailViewController.m
//  IFXPDFFactory-iOS-SamplesBrowser
//
//  Created by Sorin Nistor on 8/29/13.
//  Copyright (c) 2013 IFXFactory. All rights reserved.
//

#import "IFXFDetailViewController.h"
#import "IFXPDFFactory.h"
#import "IFXPDFAffineTransformsSample.h"
#import "IFXPDFArcsPiesSample.h"
#import "IFXPDFBezierCurvesSample.h"
#import "IFXPDFColorsSample.h"
#import "IFXPDFDocInfoAndViewerPrefsSample.h"
#import "IFXPDFEllipsesSample.h"
#import "IFXPDFFontsSample.h"
#import "IFXPDFFormXObjectsSample.h"
#import "IFXPDFImagesSample.h"
#import "IFXPDFLinesSample.h"
#import "IFXPDFOptionalContentSample.h"
#import "IFXPDFRectanglesSample.h"
#import "IFXPDFRoundedRectanglesSample.h"
#import "IFXPDFTextBoxesSample.h"
#import "IFXPDFTextLinesSample.h"

@interface IFXFDetailViewController ()
@property (strong, nonatomic) UIPopoverController *masterPopoverController;
- (void)configureView;
@end

@implementation IFXFDetailViewController {
    NSString* _sampleName;
    NSString* _sampleDescription;
    NSString* _sampleFile;
    NSString* _pdfSampleFile;
}

#pragma mark - Managing the detail item

- (void)setSampleName:(NSString*)sampleName description:(NSString*)sampleDescription file:(NSString*)sampleFile
{
    _sampleName = sampleName;
    _sampleDescription = sampleDescription;
    _sampleFile = sampleFile;
    
    // Update the view.
    [self configureView];

    if (self.masterPopoverController != nil) {
        [self.masterPopoverController dismissPopoverAnimated:YES];
    }        
}

- (void)configureView
{
    // Update the user interface for the detail item.

    if (_sampleName) {
        self.detailDescriptionLabel.text = _sampleDescription;
        self.title = _sampleName;
        self.navigationItem.rightBarButtonItem.enabled = TRUE;
        
        NSString *htmlFile = [[NSBundle mainBundle] pathForResource:_sampleFile ofType:@"html"];
        NSString* htmlString = [NSString stringWithContentsOfFile:htmlFile encoding:NSUTF8StringEncoding error:nil];
        [self.sourceCodeView loadHTMLString:htmlString baseURL:nil];
    }
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    UIBarButtonItem *runButton = [[UIBarButtonItem alloc] initWithTitle:@"Run"
                                                                  style:UIBarButtonItemStylePlain
                                                                 target:self
                                                                 action:@selector(runSample)];
    self.navigationItem.rightBarButtonItem = runButton;
    runButton.enabled = FALSE;
    
	// Do any additional setup after loading the view, typically from a nib.
    [self configureView];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        self.title = @"";
    }
    return self;
}
							
#pragma mark - Split view

- (void)splitViewController:(UISplitViewController *)splitController willHideViewController:(UIViewController *)viewController withBarButtonItem:(UIBarButtonItem *)barButtonItem forPopoverController:(UIPopoverController *)popoverController
{
    barButtonItem.title = @"IFXPDFFactory Samples";
    [self.navigationItem setLeftBarButtonItem:barButtonItem animated:YES];
    self.masterPopoverController = popoverController;
}

- (void)splitViewController:(UISplitViewController *)splitController willShowViewController:(UIViewController *)viewController invalidatingBarButtonItem:(UIBarButtonItem *)barButtonItem
{
    // Called when the view is shown again in the split view, invalidating the button and popover controller.
    [self.navigationItem setLeftBarButtonItem:nil animated:YES];
    self.masterPopoverController = nil;
}

- (void)runSample
{
    IFXPDFDocument* pdfDocument = nil;
    
    if ([_sampleName isEqualToString:@"Affine Transforms"]) {
        _pdfSampleFile = @"IFXPDFFactorySample-AffineTransforms.pdf";
        pdfDocument = [IFXPDFAffineTransformsSample run];
    }
    else if ([_sampleName isEqualToString:@"Arcs & Pies"]) {
        _pdfSampleFile = @"IFXPDFFactorySample-ArcsPies.pdf";
        pdfDocument = [IFXPDFArcsPiesSample run];
    }
    else if ([_sampleName isEqualToString:@"Bezier Curves"]) {
        _pdfSampleFile = @"IFXPDFFactorySample-BezierCurves.pdf";
        pdfDocument = [IFXPDFBezierCurvesSample run];
    }
    else if ([_sampleName isEqualToString:@"Colors & Colorspaces"]) {
        _pdfSampleFile = @"IFXPDFFactorySample-ColorsAndColorspaces.pdf";
        pdfDocument = [IFXPDFColorsSample run];
    }
    else if ([_sampleName isEqualToString:@"Doc Info & Viewer Prefs"]) {
        _pdfSampleFile = @"IFXPDFFactorySample-DocInfoAndViewerPreferences.pdf";
        pdfDocument = [IFXPDFDocInfoAndViewerPrefsSample run];
    }
    else if ([_sampleName isEqualToString:@"Ellipses"]) {
        _pdfSampleFile = @"IFXPDFFactorySample-Ellipses.pdf";
        pdfDocument = [IFXPDFEllipsesSample run];
    }
    else if ([_sampleName isEqualToString:@"Fonts"]) {
        _pdfSampleFile = @"IFXPDFFactorySample-Fonts.pdf";
        pdfDocument = [IFXPDFFontsSample run];
    }
    else if ([_sampleName isEqualToString:@"Form XObjects"]) {
        _pdfSampleFile = @"IFXPDFFactorySample-FormXObjects.pdf";
        pdfDocument = [IFXPDFFormXObjectsSample run];
    }
    else if ([_sampleName isEqualToString:@"Images"]) {
        _pdfSampleFile = @"IFXPDFFactorySample-Images.pdf";
        pdfDocument = [IFXPDFImagesSample run];
    }
    else if ([_sampleName isEqualToString:@"Lines"]) {
        _pdfSampleFile = @"IFXPDFFactorySample-Lines.pdf";
        pdfDocument = [IFXPDFLinesSample run];
    }
    else if ([_sampleName isEqualToString:@"Optional Content"]) {
        _pdfSampleFile = @"IFXPDFFactorySample-OptionalContent.pdf";
        pdfDocument = [IFXPDFOptionalContentSample run];
    }
    else if ([_sampleName isEqualToString:@"Rectangles"]) {
        _pdfSampleFile = @"IFXPDFFactorySample-Rectangles.pdf";
        pdfDocument = [IFXPDFRectanglesSample run];
    }
    else if ([_sampleName isEqualToString:@"Rounded Rectangles"]) {
        _pdfSampleFile = @"IFXPDFFactorySample-RoundedRectangles.pdf";
        pdfDocument = [IFXPDFRoundedRectanglesSample run];
    }
    else if ([_sampleName isEqualToString:@"Text Boxes"]) {
        _pdfSampleFile = @"IFXPDFFactorySample-TextBoxes.pdf";
        pdfDocument = [IFXPDFTextBoxesSample run];
    }
    else if ([_sampleName isEqualToString:@"Text Lines"]) {
        _pdfSampleFile = @"IFXPDFFactorySample-TextLines.pdf";
        pdfDocument = [IFXPDFTextLinesSample run];
    }
    
    if (pdfDocument) {
        NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
        NSString *documentsDirectory = [paths objectAtIndex:0];
        NSString *pdfFile = [documentsDirectory stringByAppendingPathComponent:_pdfSampleFile];
        [pdfDocument writeToFile:pdfFile];
        
        UIAlertView* alert = [[UIAlertView alloc] initWithTitle:@"IFXPDFFactory"
                                                        message:@"Sample created"
                                                       delegate:self
                                              cancelButtonTitle:@"OK"
                                              otherButtonTitles:@"View PDF", nil];
        [alert show];
    }
}

- (void)alertView:(UIAlertView *)alertView didDismissWithButtonIndex:(NSInteger)buttonIndex
{
    if (buttonIndex == 1) {
        QLPreviewController* ql = [[QLPreviewController alloc] init];
        ql.dataSource = self;
        [self presentViewController:ql animated:YES completion:nil];
    }
}

- (NSInteger)numberOfPreviewItemsInPreviewController:(QLPreviewController *)controller
{
    return 1;
}

- (id<QLPreviewItem>)previewController:(QLPreviewController *)controller previewItemAtIndex:(NSInteger)index
{
    return self;
}

- (NSURL*)previewItemURL
{
    NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
    NSString *documentsDirectory = [paths objectAtIndex:0];
    NSString *pdfFile = [documentsDirectory stringByAppendingPathComponent:_pdfSampleFile];
    return [NSURL fileURLWithPath:pdfFile];
}

- (NSString*)previewItemTitle
{
    return _sampleName;
}

@end
